.. _settings:

.. module:: dynts.conf

=====================
Settings
=====================

There is a ``setting`` object which can be modified at runtime to customize the
dynts environment.
To access the object type::

	from dynts.conf settings
	
.. autoclass:: dynts.conf.Settings
   :members:
   :member-order: bysource